@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2013, PyInstaller Development Team.
+# Copyright (c) 2013-2016, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License with exception
 # for distributing bootloader.
@@ -15,25 +15,32 @@ hiddenimports = ['sip',
                  'PyQt5.QtNetwork'
                  ]
 
-from PyInstaller.hooks.hookutils import qt5_qml_data, qt5_qml_plugins_binaries
+from PyInstaller.utils.hooks import (
+    qt5_qml_data,
+    qt5_qml_plugins_binaries,
+    qt5_qml_plugins_datas
+)
 
 # TODO: we should parse the Qml files to see what we need to import.
-dirs = [#'Qt',
+dirs = ['Qt',
         #'QtAudioEngine',
         #'QtGraphicalEffects',
         #'QtMultiMedia',
         'QtQml',
-        #'QtQuick',
+        'QtQuick',
         'QtQuick.2',
         #'QtSensors',
         #'QtTest'
         ]
 
-datas = []
-for dir in dirs:
-    datas.append(qt5_qml_data(dir))
+# Add base qml directories
+datas = [qt5_qml_data(dir) for dir in dirs]
 
-def hook(mod):
-    for dir in dirs:
-        mod.binaries.extend(qt5_qml_plugins_binaries(dir))
-    return mod
+# Add qmldir and *.qmltypes files
+for dir in dirs:
+    datas.extend(qt5_qml_plugins_datas(dir))
+
+# Add binaries
+binaries = []
+for dir in dirs:
+    binaries.extend(qt5_qml_plugins_binaries(dir))
